from setuptools import setup

setup(name='yamlord',
      version='0.1',
      description='wrapper for yaml package to read/write OrderedDict',
      author='Ryan J. Dillon',
      author_email='ryanjamesdillon@gmail.com',
      url='https://github.com/ryanjdillon/yamlord',
      download_url='https://github.com/ryanjdillon/yamlord/archive/0.1.tar.gz',
      license='MIT',
      packages=['yamlord'],
      zip_safe=False)
